@@ -1,4 +1,5 @@
 import hashlib
+import os
 from itertools import zip_longest
 
 from ccinput.exceptions import (
@@ -41,8 +42,9 @@ class Calculation:
         mem=1000,
         charge=0,
         multiplicity=1,
-        aux_name="calc2",
-        name="calc",
+        parse_name=False,
+        aux_name=None,
+        name=None,
         header="File created by ccinput",
         software="",
         file=None,
@@ -101,11 +103,51 @@ class Calculation:
             raise InvalidParameter(
                 f"Multiplicity must at least 1 (received '{multiplicity}')"
             )
+
+        if parse_name:
+            if not file:
+                raise InvalidParameter(
+                    f"Cannot parse the charge and multiplicity from the file name: no file given"
+                )
+
+            if "trication" in file:
+                self.charge = 3
+            elif "dication" in file:
+                self.charge = 2
+            elif "cation" in file:
+                self.charge = 1
+            elif "trianion" in file:
+                self.charge = -3
+            elif "dianion" in file:
+                self.charge = -2
+            elif "anion" in file:
+                self.charge = -1
+            elif "neutral" in file:
+                self.charge = 0
+
+            if "radical" in file or "doublet" in file:
+                self.multiplicity = 2
+            elif "triplet" in file:
+                self.multiplicity = 3
+            elif "singlet" in file:
+                self.multiplicity = 1
+
         self.verify_charge_mult()
         self.constraints = constraints
 
-        self.name = name
-        self.aux_name = aux_name
+        if name is None:
+            print(file)
+            if file is None:
+                self.name = "calc"
+            else:
+                self.name = os.path.splitext(os.path.basename(file))[0]
+        else:
+            self.name = name
+
+        if aux_name is None:
+            self.aux_name = "calc2"
+        else:
+            self.aux_name = aux_name
         self.header = header
         self.kwargs = kwargs
 
